pub struct BaseReceiverAsync<T, S>where
T: Sized,
S: ChannelStorage<T>,{ /* private fields */ }Expand description
Base async receiver
Implementations
Sourceimpl<T, S> BaseReceiverAsync<T, S>where
T: Sized,
S: ChannelStorage<T>,
impl<T, S> BaseReceiverAsync<T, S>where
T: Sized,
S: ChannelStorage<T>,
Sourcepub fn recv_blocking(&self) -> Result<T>
pub fn recv_blocking(&self) -> Result<T>
Receives a value from the channel in a blocking (synchronous) way
Sourcepub fn recv_blocking_timeout(&self, timeout: Duration) -> Result<T>
pub fn recv_blocking_timeout(&self, timeout: Duration) -> Result<T>
Receives a value from the channel in a blocking (synchronous) way with a given timeout